plushie/prop/input_purpose

Input purpose hint for IME keyboards.

Informs the platform which type of virtual keyboard or IME behavior is appropriate for a text input or text editor. Matches the values supported by the Rust renderer’s InputPurpose type.

Types

Keyboard/IME purpose hint for text inputs.

pub type InputPurpose {
  Normal
  Secure
  Terminal
  Number
  Decimal
  Phone
  Email
  Url
  Search
}

Constructors

  • Normal

    Default text input.

  • Secure

    Secure input (passwords, pins). Hides typed characters.

  • Terminal

    Terminal/console input.

  • Number

    Numeric input.

  • Decimal

    Decimal number input.

  • Phone

    Phone number input.

  • Email

    Email address input.

  • Url

    URL input.

  • Search

    Search input.

Values

pub fn to_prop_value(p: InputPurpose) -> node.PropValue

Encode an InputPurpose to its wire-format PropValue.

pub fn to_string(p: InputPurpose) -> String

Convert an InputPurpose to its wire-format string representation.

Search Document