plushie/widget/svg
SVG display widget builder.
Types
Values
pub fn content_fit(s: Svg, cf: content_fit.ContentFit) -> Svg
Set how content is fitted within the widget bounds.
SVG display widget builder.
pub fn content_fit(s: Svg, cf: content_fit.ContentFit) -> Svg
Set how content is fitted within the widget bounds.